@@ -34,6 +34,7 @@ class Client(object):
         token=None,
         replaceLocalhostString=None
     ):
+        endpoint = endpoint.rstrip('/')
         if (token != None):
             # token based
             self.workspace = cannerflow.workspace.Workspace(
@@ -64,8 +65,8 @@ class Client(object):
     def list_saved_query(self):
         return self.workspace.saved_query.list_title()
 
-    def gen_query(self, sql, cache_refresh=False, cache_ttl=86400, data_format="list"):
-        query = self.workspace.gen_query(sql, cache_refresh=cache_refresh, cache_ttl=cache_ttl, data_format=data_format)
+    def gen_query(self, sql, cache_refresh=False, cache_ttl=86400, data_format="list", fetch_by="storage"):
+        query = self.workspace.gen_query(sql, cache_refresh=cache_refresh, cache_ttl=cache_ttl, data_format=data_format, fetch_by=fetch_by)
         return query
 
     # files
